calcCurrentStatus.RdCalculate mean and variance statistics on your current breeding program.
calcCurrentStatus(bsd)
| bsd | List of breeding program data |
|---|
A vector extracting breeding population means and variances
This function is only called internally by other functions used to specify the pipeline