calcGRM.RdFunction to make a genomic relationship matrix to calculat GEBVs
calcGRM(bsd)
| bsd | List of breeding scheme data |
|---|
A genomic relationship matrix
bsd contains both variety candidates that have phenotypes and breeding population individuals that don't. Both need to be in the GRM for prediction
grm <- calcGRM(bsd)#> Error in nInd(bsd$varietyCandidates): object 'bsd' not found