chooseTrialEntries.RdFunction to select which varieties to advance to the next stage assuming they are IID (i.e., estimating genotypic values), by truncation selection
chooseTrialEntries(bsd, toTrial, fromTrial = NULL)
| bsd | The breeding scheme data list |
|---|---|
| toTrial | String the trial type the entries are going to |
| fromTrial | String the trial type the entries are coming from |
Vector of entry IDs
Accesses all data in phenoRecords to pick the highest performing candidates.