makeGrid.RdMinimum and maximum budget percentages for each part and step sizes These vectors are in bsd Returns a list with all the outputs
makeGrid(bsd)
| bsd | List of breeding scheme data |
|---|
List with initial and end means and variances
Call this function to set up optimization
bsd <- makeGrid(bsd)#> Error in seq(from = bsd$minPercentage[1], to = bsd$maxPercentage[1], by = bsd$percentageStep[1]): object 'bsd' not found