plotLoessPred.RdMake a nice hexbin plot with the summary from loessPredCount
plotLoessPred( nSim = nrow(resultMat), resultMat, xlim = NULL, ylim = NULL, budg1 = 1, budg2 = 2, binMeanContrast = 3 )
| nSim | Integer Predictions and counts for the first nSim simulations |
|---|---|
| resultMat | Tibble the simulation results |
| xlim | Real max and min for plot |
| ylim | Real max and min for plot |
| budg1 | Integer which column of percent budget to make plot for x-axis |
| budg2 | Integer which column of percent budget to make plot for y-axis |
| binMeanContrast | Numeric a higher value makes the peak stand out more |
A list with bin counts and means and results from LOESS predictions
Makes a plot