selectParents.RdFunction to select which breeding population individuals to use as parents to advance the population
selectParents(bsd)
| bsd | The breeding scheme data list |
|---|
Data.frame with pedigree ccMat-based optimal contributions
Accesses phenoRecords to predict GEBVs among breeding population then calculates optimal contributions with those GEBVs and a pedigree-based coefficient of coancestry matrix.